==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/rendering/XCanvas.hpp <==
#ifndef _COM_SUN_STAR_RENDERING_XCANVAS_HPP_
#define _COM_SUN_STAR_RENDERING_XCANVAS_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_RENDERING_XCANVAS_HDL_
#include "com/sun/star/rendering/XCanvas.hdl"
#endif

#ifndef _COM_SUN_STAR_RENDERING_XCACHEDPRIMITIVE_HPP_
#include "com/sun/star/rendering/XCachedPrimitive.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_FONTINFO_HPP_
#include "com/sun/star/rendering/FontInfo.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_STROKEATTRIBUTES_HPP_
#include "com/sun/star/rendering/StrokeAttributes.hpp"
#endif
#ifndef _COM_SUN_STAR_GEOMETRY_REALPOINT2D_HPP_
#include "com/sun/star/geometry/RealPoint2D.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_XPOLYPOLYGON2D_HPP_
#include "com/sun/star/rendering/XPolyPolygon2D.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_TEXTURE_HPP_
#include "com/sun/star/rendering/Texture.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_VOLATILECONTENTDESTROYEDEXCEPTION_HPP_
#include "com/sun/star/rendering/VolatileContentDestroyedException.hpp"
#endif
#ifndef _COM_SUN_STAR_LANG_ILLEGALARGUMENTEXCEPTION_HPP_
#include "com/sun/star/lang/IllegalArgumentException.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_STRINGCONTEXT_HPP_
#include "com/sun/star/rendering/StringContext.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_XCANVASFONT_HPP_
#include "com/sun/star/rendering/XCanvasFont.hpp"
#endif
#ifndef _COM_SUN_STAR_GEOMETRY_REALBEZIERSEGMENT2D_HPP_
#include "com/sun/star/geometry/RealBezierSegment2D.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_RUNTIMEEXCEPTION_HPP_
#include "com/sun/star/uno/RuntimeException.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_RENDERSTATE_HPP_
#include "com/sun/star/rendering/RenderState.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_FONTREQUEST_HPP_
#include "com/sun/star/rendering/FontRequest.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_XTEXTLAYOUT_HPP_
#include "com/sun/star/rendering/XTextLayout.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_XGRAPHICDEVICE_HPP_
#include "com/sun/star/rendering/XGraphicDevice.hpp"
#endif
#ifndef _COM_SUN_STAR_BEANS_PROPERTYVALUE_HPP_
#include "com/sun/star/beans/PropertyValue.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_XINTERFACE_HPP_
#include "com/sun/star/uno/XInterface.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_VIEWSTATE_HPP_
#include "com/sun/star/rendering/ViewState.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_XBITMAP_HPP_
#include "com/sun/star/rendering/XBitmap.hpp"
#endif
#ifndef _COM_SUN_STAR_GEOMETRY_MATRIX2D_HPP_
#include "com/sun/star/geometry/Matrix2D.hpp"
#endif
#ifndef _COM_SUN_STAR_GEOMETRY_XMAPPING2D_HPP_
#include "com/sun/star/geometry/XMapping2D.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif

inline const ::com::sun::star::uno::Type& SAL_CALL getCppuType( const ::com::sun::star::uno::Reference< ::com::sun::star::rendering::XCanvas >* ) SAL_THROW( () )
{
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_INTERFACE, "com.sun.star.rendering.XCanvas" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
}

::com::sun::star::uno::Type const & ::com::sun::star::rendering::XCanvas::static_type(void *) {
    return ::getCppuType(static_cast< ::com::sun::star::uno::Reference< ::com::sun::star::rendering::XCanvas > * >(0));
}

#endif // _COM_SUN_STAR_RENDERING_XCANVAS_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/rendering/XCanvas.hpp <==
#ifndef _COM_SUN_STAR_RENDERING_XCANVAS_HPP_
#define _COM_SUN_STAR_RENDERING_XCANVAS_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_RENDERING_XCANVAS_HDL_
#include "com/sun/star/rendering/XCanvas.hdl"
#endif

#ifndef _COM_SUN_STAR_RENDERING_XCACHEDPRIMITIVE_HPP_
#include "com/sun/star/rendering/XCachedPrimitive.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_FONTINFO_HPP_
#include "com/sun/star/rendering/FontInfo.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_STROKEATTRIBUTES_HPP_
#include "com/sun/star/rendering/StrokeAttributes.hpp"
#endif
#ifndef _COM_SUN_STAR_GEOMETRY_REALPOINT2D_HPP_
#include "com/sun/star/geometry/RealPoint2D.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_XPOLYPOLYGON2D_HPP_
#include "com/sun/star/rendering/XPolyPolygon2D.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_TEXTURE_HPP_
#include "com/sun/star/rendering/Texture.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_VOLATILECONTENTDESTROYEDEXCEPTION_HPP_
#include "com/sun/star/rendering/VolatileContentDestroyedException.hpp"
#endif
#ifndef _COM_SUN_STAR_LANG_ILLEGALARGUMENTEXCEPTION_HPP_
#include "com/sun/star/lang/IllegalArgumentException.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_STRINGCONTEXT_HPP_
#include "com/sun/star/rendering/StringContext.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_XCANVASFONT_HPP_
#include "com/sun/star/rendering/XCanvasFont.hpp"
#endif
#ifndef _COM_SUN_STAR_GEOMETRY_REALBEZIERSEGMENT2D_HPP_
#include "com/sun/star/geometry/RealBezierSegment2D.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_RUNTIMEEXCEPTION_HPP_
#include "com/sun/star/uno/RuntimeException.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_RENDERSTATE_HPP_
#include "com/sun/star/rendering/RenderState.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_FONTREQUEST_HPP_
#include "com/sun/star/rendering/FontRequest.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_XTEXTLAYOUT_HPP_
#include "com/sun/star/rendering/XTextLayout.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_XGRAPHICDEVICE_HPP_
#include "com/sun/star/rendering/XGraphicDevice.hpp"
#endif
#ifndef _COM_SUN_STAR_BEANS_PROPERTYVALUE_HPP_
#include "com/sun/star/beans/PropertyValue.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_XINTERFACE_HPP_
#include "com/sun/star/uno/XInterface.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_VIEWSTATE_HPP_
#include "com/sun/star/rendering/ViewState.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_XBITMAP_HPP_
#include "com/sun/star/rendering/XBitmap.hpp"
#endif
#ifndef _COM_SUN_STAR_GEOMETRY_MATRIX2D_HPP_
#include "com/sun/star/geometry/Matrix2D.hpp"
#endif
#ifndef _COM_SUN_STAR_GEOMETRY_XMAPPING2D_HPP_
#include "com/sun/star/geometry/XMapping2D.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif

namespace com { namespace sun { namespace star { namespace rendering {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::rendering::XCanvas const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_INTERFACE, "com.sun.star.rendering.XCanvas" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::uno::Reference< ::com::sun::star::rendering::XCanvas > const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::uno::Reference< ::com::sun::star::rendering::XCanvas > >::get();
}

::com::sun::star::uno::Type const & ::com::sun::star::rendering::XCanvas::static_type(void *) {
    return ::getCppuType(static_cast< ::com::sun::star::uno::Reference< ::com::sun::star::rendering::XCanvas > * >(0));
}

#endif // _COM_SUN_STAR_RENDERING_XCANVAS_HPP_
